###########################
#Data and Code for: Forecasting the Results of Experiments: Piloting an Elicitation Strategy
#Inputs: Data.rda
#Outputs:
#   -Table 1
#   -Table 2
#   -Table A1
#   -Table A2
#   -Figure 1
###########################

#Install and load required packages

  pkgTest <- function(x)
  {
    if (!require(x,character.only = TRUE))
    {
      install.packages(x,dep=TRUE)
      if(!require(x,character.only = TRUE)) stop("Package not found")
    }
    return("OK")
  }

  global.libraries <- c("tidyverse","DeclareDesign","readxl","expss","data.table","multiwayvcov","lmtest","kableExtra","plotrix","knitr","texPreview")

  sapply(as.list(global.libraries), pkgTest)

#Load data
  setwd("") #Input working directory containing "Data.rda" 
  load("Data.rda")

#Table 1 : FORECASTS BY EXPERIMENT

  #Table 1, column 1 (forecast mean) and 2 (forecast sd)
  
    T1_C1m2sd<-bind_rows(
      Data %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(H_HIV==1) %>%  	summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Drop==1) %>% 	summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Bus==1) %>%  	summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Exam==1) %>% 	summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T1==1) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T2==1) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T3==1) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T1==1) %>% 	summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T2==1) %>% 	summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T3==1) %>% 	summarize(mean(Pred),sd(Pred))
    ) %>% round(2)

  #Table 1, column 3 (forecast standard errors)

    #Clustered standard errors for means pooled across individuals
    se_All<-lm_robust(Pred~1, data=subset(Data), clusters = ResponseId, se_type = "stata")$std.error[1] %>%as.data.frame()
    colnames(se_All)<-c("std.error(Pred)")

    #Standard errors for unpooled means
    T1_C3se<-bind_rows(
      se_All,
      Data %>% filter(H_HIV==1) %>%     summarize(std.error(Pred)),
      Data %>% filter(E_Drop==1) %>%    summarize(std.error(Pred)),
      Data %>% filter(E_Bus==1) %>%     summarize(std.error(Pred)),
      Data %>% filter(E_Exam==1) %>%    summarize(std.error(Pred)),
      Data %>% filter(C_Food_T1==1) %>% summarize(std.error(Pred)),
      Data %>% filter(C_Food_T2==1) %>% summarize(std.error(Pred)),
      Data %>% filter(C_Food_T3==1) %>% summarize(std.error(Pred)),
      Data %>% filter(C_Hea_T1==1) %>%  summarize(std.error(Pred)),
      Data %>% filter(C_Hea_T2==1) %>%  summarize(std.error(Pred)),
      Data %>% filter(C_Hea_T3==1) %>%  summarize(std.error(Pred)),
    ) %>% round(2)

  #Table 1, columns 4 and 5 (sample sizes)

    T1_C4ni5nf<-bind_rows(
      Data %>%                          summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(H_HIV==1) %>%     summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(E_Drop==1) %>%    summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(E_Bus==1) %>%     summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(E_Exam==1) %>%    summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(C_Food_T1==1) %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(C_Food_T2==1) %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(C_Food_T3==1) %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(C_Hea_T1==1) %>%  summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(C_Hea_T2==1) %>%  summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(C_Hea_T3==1) %>%  summarize(length(unique(ResponseId)),length(ResponseId))
    ) %>% round(2)

  #Bind columns
  
    T1<-cbind(T1_C1m2sd,T1_C3se,T1_C4ni5nf)

  #Parentheses around SD and SE

    T1[,2]<-paste0("(",format(unlist(T1[,2])),")")
    T1[,3]<-paste0("(",format(unlist(T1[,3])),")")

  #Row names

    rownames(T1)<- c("\\textbf{Panel A: All pred.}","HIV testing",
      "Dropout (reversed)","Business participation",
      "Test scores","T1 (Cash) ","T2 (T1+Asset) ","TA1 (T2+Nutrition) ",
      "T1 (Cash)","T2 (T1+Asset)","TA1 (T2+Nutrition)")

  #Generate table 1 using Kable

    table1<-kable(T1, "latex", booktabs = T, digits = 3, escape = F, align=rep('c', 5), 
    col.names = c("Mean","SD","SE","$n_i$","$n_f$"))   %>%
    kable_styling( position = "center") %>% 
    pack_rows("Panel A: Yang et al.", 2,2) %>%
    pack_rows("Panel B: Blimpo et al.", 3, 5) %>%
    pack_rows("Panel C: Bouguen et al.", 6, 11) %>%
    pack_rows("Food consumption", 6, 8, bold = FALSE, italic = TRUE) %>%
    pack_rows("Health consumption", 9, 11, bold = FALSE, italic = TRUE)

  #Preview table 1 (requires Latex)
  
    #tex_preview(table1)

#Table 2 : FORECASTS BY SURVEY FORMAT

  #Table 2, column 1 (forecast mean) and 2 (forecast sd)
 
    T2_C1m2sd <- bind_rows(
      Data %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)")  %>% as.data.frame()  %>% round(2)

  #Table 2, column 3 (forecast se)

   #Standard errors by condition, clustered at the individual level

    #Reference 
      se_m_ref_Small<-lm_robust(Pred~1, data=subset(Data, TreatLargeRef==0), clusters = ResponseId, se_type = "stata")$std.error
      se_m_ref_Large<-lm_robust(Pred~1, data=subset(Data, TreatLargeRef==1), clusters = ResponseId, se_type = "stata")$std.error

    #SD 
      se_m_sd_No<-lm_robust(Pred~1, data=subset(Data, AnySD==0), clusters = ResponseId, se_type = "stata")$std.error
      se_m_sd_Yes<-lm_robust(Pred~1, data=subset(Data, AnySD==1), clusters = ResponseId, se_type = "stata")$std.error

    #Slider       
      se_m_sli_No<-lm_robust(Pred~1, data=subset(Data, AnySlider==0), clusters = ResponseId, se_type = "stata")$std.error
      se_m_sli_Yes<-lm_robust(Pred~1, data=subset(Data, AnySlider==1), clusters = ResponseId, se_type = "stata")$std.error

    #Slider (small vs large) 
      se_m_SliBouSmall<-lm_robust(Pred~1, data=subset(Data, AnySlider==1 & AnyWide==0), clusters = ResponseId, se_type = "stata")$std.error
      se_m_SliBouLarge<-lm_robust(Pred~1, data=subset(Data, AnySlider==1 & AnyWide==1), clusters = ResponseId, se_type = "stata")$std.error

    #Bind SEs
      T1_C3se<-rbind(se_m_ref_Small, se_m_ref_Large, se_m_sd_No, 
        se_m_sd_Yes, se_m_sli_No, se_m_sli_Yes, se_m_SliBouSmall, se_m_SliBouLarge) %>% round(2)

  #Table 2, columns 4 and 5 (sample sizes)

    T2_C4ni5nf <- bind_rows(
      Data %>% group_by(TreatLargeRef) %>% summarize(length(unique(ResponseId)),length(ResponseId)),    
      Data %>% group_by(AnySD) %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% group_by(AnySlider) %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(AnySlider==1) %>% group_by(AnyWide) %>% summarize(length(unique(ResponseId)),length(ResponseId))
    ) %>% select(c("length(unique(ResponseId))","length(ResponseId)"))   %>% as.data.frame()  %>% round(0)

  #Table 2, columns 6 (p values)

    #P-values pooling across comparions, clustered at the individual level.

      #Small vs large reference
      pRefLar <- lm_robust(Pred~TreatLargeRef, data=Data, cluster = ResponseId, se_type = "stata")$p.value[2] %>% round(2)

      #SD vs non-SD
      pAnySD <- lm_robust(Pred~AnySD, data=Data, cluster = ResponseId, se_type = "stata")$p.value[2] %>% round(2)

      #Slider
      pAnySli <- lm_robust(Pred~AnySlider, data=Data, cluster = ResponseId, se_type = "stata")$p.value[2] %>% round(2)

      #Slider (small vs large) 
      pAnyWide <- lm_robust(Pred~AnyWide, data=subset(Data, AnySlider==1), cluster = ResponseId, se_type = "stata")$p.value[2] %>% round(2)

  #Bind rows 
 
   T2_C6p <-rbind("",pRefLar,"",pAnySD,"",pAnySli,"",pAnyWide) 

  #Bind cols
  
    T2<-cbind(T2_C1m2sd,T1_C3se,T2_C4ni5nf,T2_C6p)

  #Parentheses around SD and SE
   
    T2[,2]<-paste0("(",format(unlist(T2[,2])),")")
    T2[,3]<-paste0("(",format(unlist(T2[,3])),")")

  #Row and col names
    
    rownames(T2)<- c("Small (0.1 SD)", "Large (0.3 SD)","Raw units", "Standard deviations", "Text" , "Slider" ,  "Small (0.5 SD)", "Large (1.0 SD)")
    colnames(T2)<- c("Mean","SD","SE","$n_i$","$n_f$","$p$")

  #Generate table 2 using Kable
    
    table2<-kable(T2, "latex", booktabs = T, digits = 3, escape = F, align=rep('c', 5)) %>%
    kable_styling( position = "center") %>% 
    pack_rows("Panel A: Reference", 1,2) %>%
    pack_rows("Panel B: Units", 3,4) %>%
    pack_rows("Panel C: Entry", 5,6) %>%
    pack_rows("Panel D: Slider bounds", 7,8) 

  #Preview table 2 (requires Latex)

    #tex_preview(table2)
  
#Appendix Table 1 : FORECASTS BY SAMPLE AND TYPE 

  #Table A1, column 1 (forecast mean) and 2 (forecast sd)

    TA1_C1m2sd <- bind_rows(
      #By group
      Data %>% filter(Group=="PP_ListServ") %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(Group=="PP_Twitter") %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(Group=="PP_xOtr") %>% summarize(mean(Pred),sd(Pred)),
      #By background
      Data %>% filter(Background=="Faculty") %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(Background=="PhD student") %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(Background=="Researcher") %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(Background=="Practitioner") %>% summarize(mean(Pred),sd(Pred))
      )  %>% as.data.frame()  %>% round(2)

  #Table A1, column 3 (forecast standard errors)

    #Clustered standard errors for means pooled across individuals
      #By group 
        se_m_Listserv<-lm_robust(Pred~1, data=subset(Data, Group=="PP_ListServ"), clusters = ResponseId, se_type = "stata")$std.error
        se_m_Twitter<-lm_robust(Pred~1, data=subset(Data, Group=="PP_Twitter"), clusters = ResponseId, se_type = "stata")$std.error
        se_m_Other<-lm_robust(Pred~1, data=subset(Data, Group=="PP_xOtr"), clusters = ResponseId, se_type = "stata")$std.error
    
      #By type
        se_m_Faculty<-lm_robust(Pred~1, data=subset(Data, Background=="Faculty"), clusters = ResponseId, se_type = "stata")$std.error
        se_m_PhD<-lm_robust(Pred~1, data=subset(Data, Background=="PhD student"), clusters = ResponseId, se_type = "stata")$std.error
        se_m_Researcher<-lm_robust(Pred~1, data=subset(Data, Background=="Researcher"), clusters = ResponseId, se_type = "stata")$std.error
        se_m_Practitioner<-lm_robust(Pred~1, data=subset(Data, Background=="Practitioner"), clusters = ResponseId, se_type = "stata")$std.error

      #Bind rows
      TA1_C3se<-rbind(se_m_Listserv,se_m_Twitter, se_m_Other, se_m_Faculty, se_m_PhD, se_m_Researcher, se_m_Practitioner) %>% round(2)

  #Table A1, columns 4 and 5 (sample sizes)
      
    TA1_C4ni5nf <- bind_rows(
      #By group
      Data %>% filter(Group=="PP_ListServ") %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(Group=="PP_Twitter") %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(Group=="PP_xOtr") %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      #By background
      Data %>% filter(Background=="Faculty") %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(Background=="PhD student") %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(Background=="Researcher") %>% summarize(length(unique(ResponseId)),length(ResponseId)),
      Data %>% filter(Background=="Practitioner") %>% summarize(length(unique(ResponseId)),length(ResponseId))
    )  %>% as.data.frame()  %>% round(2)

  #Table A1, column 6 (p values)

    #Standard errors are clustered at the individual level
    #By group 
      pTwit <- lm_robust(Pred~Group, data=Data, cluster = ResponseId, se_type = "stata")$p.value[2] %>% round(2)
      pOtr <- lm_robust(Pred~Group, data=Data, cluster = ResponseId, se_type = "stata")$p.value[3] %>% round(2)

    #By background
      pPhD <- lm_robust(Pred~Background, data=Data, cluster = ResponseId, se_type = "stata")$p.value[2] %>% round(2)
      pRes <- lm_robust(Pred~Background, data=Data, cluster = ResponseId, se_type = "stata")$p.value[3] %>% round(2)
      pPrac <- lm_robust(Pred~Background, data=Data, cluster = ResponseId, se_type = "stata")$p.value[4] %>% round(2)

    #p values
    TA1_c6p <- rbind("", pTwit, pOtr, "", pPhD, pRes, pPrac)

  #Bind columns

    TA1 <- cbind(TA1_C1m2sd, TA1_C3se, TA1_C4ni5nf, TA1_c6p)

  #Parentheses around SD and SE

    TA1[,2] <- paste0("(",format(unlist(TA1[,2])),")")
    TA1[,3] <- paste0("(",format(unlist(TA1[,3])),")")

  #Row and col names

    rownames(TA1)<- c("Listserv","Twitter","Other","Faculty","PhD student","Researcher","Practitioner")
    colnames(TA1)<- c("Mean","SD","SE","$n_i$","$n_f$","$p$")

  #Generate table A1 using Kable

    tableA1<-kable(TA1, "latex", booktabs = T, digits = 3, escape = F, align=rep('c', 5)) %>%
    kable_styling( position = "center") %>% 
    pack_rows("Panel A: Sample", 1,3) %>%
    pack_rows("Panel B: Type", 4,7) 

  #Preview table A1 (requires Latex)

    #tex_preview(tableA1)

#Appendix Table 2 : FORECASTS BY EXPERIMENT AND SURVEY FORMAT
  
  #Table A2, rows 1 (forecast means) and 2 (forecast sds) for: HIV testing

    TA2_R1m2sd <- bind_rows(
      Data %>% filter(H_HIV==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(H_HIV==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(H_HIV==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(H_HIV==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 3 (forecast means) and 4 (forecast sds) for: Dropout (reverse coded)

    TA2_R3m4sd <- bind_rows(
      Data %>% filter(E_Drop==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Drop==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)), 
      Data %>% filter(E_Drop==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Drop==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 5 (forecast means) and 6 (forecast sds) for: Business participation

    TA2_R5m6sd <- bind_rows(
      Data %>% filter(E_Bus==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Bus==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Bus==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Bus==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 7 (forecast means) and 8 (forecast sds) for: Test scores

    TA2_R7m8sd <- bind_rows(
      Data %>% filter(E_Exam==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Exam==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Exam==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(E_Exam==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)
  
  #Table A2, rows 9 (forecast means) and 10 (forecast sds) for: Food consumption (T1)

    TA2_R9m10sd <- bind_rows(
      Data %>% filter(C_Food_T1==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T1==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T1==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T1==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 11 (forecast means) and 12 (forecast sds) for: Food consumption (T2)

    TA2_R11m12sd <- bind_rows(
      Data %>% filter(C_Food_T2==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T2==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T2==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T2==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 13 (forecast means) and 14 (forecast sds) for: Food consumption (T3)

    TA2_R13m14sd <- bind_rows(
      Data %>% filter(C_Food_T3==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% filter(C_Food_T3==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T3==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Food_T3==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 15 (forecast means) and 16 (forecast sds) for: Health consumption (T1)

    TA2_R15m16sd <- bind_rows(
      Data %>% filter(C_Hea_T1==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% filter(C_Hea_T1==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T1==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T1==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 17 (forecast means) and 18 (forecast sds) for: Health consumption (T2)

    TA2_R17m18sd <- bind_rows(	
      Data %>% filter(C_Hea_T2==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% filter(C_Hea_T2==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% filter(C_Hea_T2==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T2==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, rows 19 (forecast means) and 20 (forecast sds) for: Health consumption (T3)

    TA2_R19m20sd <- bind_rows(
      Data %>% filter(C_Hea_T3==1) %>% group_by(TreatLargeRef) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% filter(C_Hea_T3==1) %>% group_by(AnySD) %>% summarize(mean(Pred),sd(Pred)),    
      Data %>% filter(C_Hea_T3==1) %>% group_by(AnySlider) %>% summarize(mean(Pred),sd(Pred)),
      Data %>% filter(C_Hea_T3==1 & AnySlider==1) %>% group_by(AnyWide) %>% summarize(mean(Pred),sd(Pred))
    ) %>% select(c("mean(Pred)"),"sd(Pred)") %>% t %>% as.data.frame() %>% round(2)

  #Table A2, row 21 (sample size: individual)

    TA2_R21ni <- bind_rows(
      Data %>% group_by(TreatLargeRef) %>% summarize(length(unique(ResponseId))),    
      Data %>% group_by(AnySD) %>% summarize(length(unique(ResponseId))),    
      Data %>% group_by(AnySlider) %>% summarize(length(unique(ResponseId))),
      Data %>% filter(AnySlider==1) %>% group_by(AnyWide) %>% summarize(length(unique(ResponseId)))
    ) %>% select(c("length(unique(ResponseId))")) %>% t %>% as.data.frame() %>% round(0)
   
  #Table A2, row 22 (sample size: forecasts)

    TA2_R22nf <- bind_rows(
      Data %>% group_by(TreatLargeRef) %>% summarize(length(ResponseId)),
      Data %>% group_by(AnySD) %>% summarize(length(ResponseId)),   
      Data %>% group_by(AnySlider) %>% summarize(length(ResponseId)),
      Data %>% filter(AnySlider==1) %>% group_by(AnyWide) %>% summarize(length(ResponseId))
    ) %>% select(c("length(ResponseId)")) %>% t %>% as.data.frame() %>% round(0)

  #Bind rows
    
    TA2 <- bind_rows(TA2_R1m2sd,TA2_R3m4sd,TA2_R5m6sd,TA2_R7m8sd,TA2_R9m10sd,TA2_R11m12sd,TA2_R13m14sd,TA2_R15m16sd,TA2_R17m18sd,TA2_R19m20sd,TA2_R21ni,TA2_R22nf) 

  #Row names

    rownames(TA2) <- c("HIV testing","$~$$~$","Dropout (reversed)","$~$","Business participation","$~~$",
       "Test scores","$~~~$","T1 (Cash) ","~","T2 (T1+Asset) ","~~","T3 (T2+Nutrition) ","~~~",
       "T1 (Cash)","~~~~","T2 (T1+Asset)","$~$~","T3 (T2+Nutrition)","$~$~~","$n_i$","$n_f$")
    colnames(TA2) <- c("Small", "Large", "Raw units", "Std. dev.", "Text", "Slider", "Small", "Large")
 
  #Parentheses around SD

    TA2[2,] <- paste0("(",format(unlist(TA2[2,])),")")
    TA2[4,] <- paste0("(",format(unlist(TA2[4,])),")")
    TA2[6,] <- paste0("(",format(unlist(TA2[6,])),")")
    TA2[8,] <- paste0("(",format(unlist(TA2[8,])),")")
    TA2[10,] <- paste0("(",format(unlist(TA2[10,])),")")
    TA2[12,] <- paste0("(",format(unlist(TA2[12,])),")")
    TA2[14,] <- paste0("(",format(unlist(TA2[14,])),")")
    TA2[16,] <- paste0("(",format(unlist(TA2[16,])),")")
    TA2[18,] <- paste0("(",format(unlist(TA2[18,])),")")
    TA2[20,] <- paste0("(",format(unlist(TA2[20,])),")")

  #Generate table A2 using Kable
    tableA2<-kable(TA2, "latex", booktabs = T, digits = 3, escape = F, align=rep('c', 5))  %>%
      kable_styling( position = "center") %>% 
      row_spec(20, hline_after = T) %>%
      pack_rows("Panel A: Yang et al.", 1,2) %>%
      pack_rows("Panel B: Blimpo et al.", 3, 8) %>%
      pack_rows("Panel C: Bouguen et al.", 9, 20) %>%
      pack_rows("Food consumption", 9, 14, bold = FALSE, italic = TRUE) %>%
      pack_rows("Health consumption", 15, 20, bold = FALSE, italic = TRUE) %>%
      add_header_above(c(" " = 1, "Reference" = 2, "Units" = 2, "Entry" = 2 , "Slider bounds" = 2)) 

  #Preview table A2 (requires Latex)

    #tex_preview(tableA2)

#Figure 1 : FORECASTS BY SMALL VERSUS LARGE SLIDER BOUNDS

  ggplot(subset(Data, AnySlider==1), aes(Pred, colour = as.factor(AnyWide))) + 
  stat_ecdf()+ #cdf
  ggtitle("CDF of Forecasts") +
  xlab("Predicted Causal Effect in SD") +
  ylab("") +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(colour = "black"),
        axis.text.x = element_text(size = 11),
        legend.justification=c(1,1),legend.position=c(.9,.35),legend.title=element_blank(),
        plot.title = element_text(size=11, face="bold"),
        text = element_text(size=11)) +
        scale_color_manual(values=c('#7ca6c0','#c05746'),
        name="", labels=c("Small slider (0.5 SD)","Large slider (1.0 SD)")) 
